@@ -16,8 +16,6 @@ def get_msg_client():
         cfg.slack_channel = None
 
     if (cfg.slack_channel
-            and cfg.action in [
-                'update', 'create', 'delete', 'cancel', 'continue']
             and 'IBOX_SLACK_TOKEN' in os.environ
             and 'IBOX_SLACK_USER' in os.environ):
         slack_web = slack.WebClient(token=os.environ['IBOX_SLACK_TOKEN'])
